@@ -1,5 +1,5 @@
 webmockr_lightswitch <- new.env()
-#webmockr_lightswitch$httr <- FALSE
+webmockr_lightswitch$httr <- FALSE
 webmockr_lightswitch$crul <- FALSE
 
 #' Enable or disable webmockr
@@ -23,12 +23,12 @@ enable <- function(options = list()) {
 #' @export
 #' @rdname enable
 enabled <- function(adapter = "crul") {
-  adapters <- c('crul')
+  adapters <- c('crul', 'httr')
   if (!adapter %in% adapters) {
     stop("'adapter' must be in the set ", 
       paste0(adapters, collapse = ", "))
   }
-  webmockr_lightswitch$crul
+  webmockr_lightswitch[[adapter]]
 }
 
 #' @export
